searchData={"items":[{"type":"module","title":"Hammer.Plug","doc":"A plug which rate-limits requests, using the Hammer library.","ref":"Hammer.Plug.html"},{"type":"module","title":"Usage example: - Hammer.Plug","doc":"# Minimal\n    plug Hammer.Plug, [\n      rate_limit: {\"video:upload\", 60_000, 10},\n      by: {:session, :user_id}\n    ] when action == :upload_video_file\n    # Using all options\n    plug Hammer.Plug, [\n      rate_limit: {\"chat:message:post\", 60_000, 20},\n      by: {:session, :user, &Helpers.get_user_id/2},\n      when_nil: :raise,\n      on_deny: &Helpers.handle_deny/2\n    ] when action == :post_chat_message","ref":"Hammer.Plug.html#module-usage-example"},{"type":"module","title":"Options - Hammer.Plug","doc":"### :rate_limit (`{prefix::string, time_scale::int, limit::int}`)\nRequired. A tuple of three elements, a string prefix that identifies\nthis particular rate-limiter, an integer time-scale in milliseconds, and\nan integer limit. These are the same as the first three arguments to the\n`check_rate` function in the\n[Hammer](https://hexdocs.pm/hammer/Hammer.html#check_rate/3) module.\nRequests from a single client (as identified by the `:by` parameter) will\nbe rate-limited to the specified limit within the specified timeframe.\nBy default, requests which are over the limit will be halted, and a\n`429 Too Many Requests` response will be sent.\n#### Examples\n    rate_limit: {\"chat:message:post\", 20_000, 5}\n    rate_limit: {\"login\", 60_000, 10}\n### :by\nThe method by which to choose a \"unique\" identifier for the request client.\nOptional, defaults to `:ip`.\nValid options:\n- `:ip` -> Use the IP address of the request\n- `{:session, key}` -> where `key` is an atom, choose this value from the\n  session\n- `{:session, key, func}` -> where `key` is an atom and `func` is a\n   function of the form `&SomeModule.some_function/1`, choose the value\n   from the session, and then apply the supplied function, then use the\n   return value as the identifier\n- `{:conn, func}` -> where `func` is a function of the form\n   `&SomeModule.some_function/1` which returns a value from the conn to\n   be used as the identifier\n#### Examples\n    by: :ip\n    by: {:session, :user_id}\n    by: {:session, :user, &Helpers.get_user_id/1} # where `get_user_id/1` is\n    equivalent to `fn (u) -> u.id end`\n    by: {:conn, &Helpers.get_email_from_request/1} # where email_from_request/1\n    is equivalent to `fn (conn) -> conn.params[\"email\"] end`\n### :when_nil\nStrategy to use when the request identifier value (as chosen by the `:by`\nparameter), is `nil`.\nOptional, defaults to `:use_nil`\nThe most likely scenario is that when using a `:by` strategy like\n`{:session, :user_id}`, the `:user_id` value might actually be `nil`, for\nrequests coming from clients that are not logged-in, for example.\nIn general, it is recommended that you only use the `:session` strategy\non routes that you know will only be available to clients which have the\nappropriate session established.\nValid options:\n- `:use_nil` -> Use the nil value. Not very useful, as this would mean that\n  one rate-limiter would apply to all such requests\n- `:pass` -> skip the rate-limit check, and allow the request to proceed\n- `:raise` -> raise a `Hammer.Plug.NilError` exception\n#### Examples\n    when_nil: :pass\n### :on_deny\nA plug function to be invoked when a request is deemed to have exceeded the\nrate-limit.\nOptional, defaults to sending a `429 Too Many Requests` response and halting\nthe connection.\n#### Examples\n    on_deny: &Helpers.handle_rate_limit_deny/2\n    # where `handle_rate_limit_deny/2` is something like:\n    #\n    #     def handle_rate_limit_deny(conn, _opts) do\n    #       ...\n    #     end","ref":"Hammer.Plug.html#module-options"},{"type":"function","title":"Hammer.Plug.default_on_deny_handler/2","doc":"","ref":"Hammer.Plug.html#default_on_deny_handler/2"},{"type":"exception","title":"Hammer.Plug.NilError","doc":"","ref":"Hammer.Plug.NilError.html"},{"type":"exception","title":"Hammer.Plug.NoRateLimitError","doc":"","ref":"Hammer.Plug.NoRateLimitError.html"},{"type":"extras","title":"Overview","doc":"","ref":"overview.html"},{"type":"extras","title":"A rate limiting plug for Hammer - Overview","doc":"[Hammer](https://github.com/ExHammer/hammer) is a rate-limiter for Elixir, with pluggable storage backends.\n\nThis library is a [plug](https://hexdocs.pm/plug/readme.html) helper, to easily add rate-limiting to Phoenix applications,\nor any Elixir system that uses plug.\n\nExample:\n\n```elixir\n# Allow ten uploads per 60 seconds\nplug Hammer.Plug, [\n  rate_limit: {\"video:upload\", 60_000, 10},\n  by: {:session, :user_id}\n] when action == :upload_video_file\n\ndef upload_video_file(conn, _opts) do\n  # ...\nend\n```","ref":"overview.html#a-rate-limiting-plug-for-hammer"},{"type":"extras","title":"Documentation - Overview","doc":"See the [Hammer documentation page](https://hexdocs.pm/hammer) for more info on Hammer itself.\n\nSee the [Hammer.Plug docs](https://hexdocs.pm/hammer_plug) for more info about this library and how to use it, specifically the [Hammer.Plug](https://hexdocs.pm/hammer_plug/Hammer.Plug.html#content) module.","ref":"overview.html#documentation"},{"type":"extras","title":"Installation - Overview","doc":"Hammer-Plug is avaliable [available in Hex](https://hex.pm/docs/publish), the package can be installed by adding `hammer_plug` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hammer, \"~> 6.0\"},\n    {:hammer_plug, \"~> 3.0\"}\n  ]\nend\n```","ref":"overview.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"3.1.0 (2024-12-20) - Changelog","doc":"","ref":"changelog.html#3-1-0-2024-12-20"},{"type":"extras","title":"Changed - Changelog","doc":"- End-of-life. Please consider using custom function plugs suggested in the compilation warnings instead. We will not be releasing any more versions. See the [Hammer documentation](https://hexdocs.pm/hammer/7.0.0-rc.3/tutorial.html#using-hammer-as-a-plug-in-phoenix) for more information.","ref":"changelog.html#changed"},{"type":"extras","title":"3.0.0 (2022-11-25) - Changelog","doc":"","ref":"changelog.html#3-0-0-2022-11-25"},{"type":"extras","title":"Changed - Changelog","doc":"- Support Elixir >= 1.11\n- Adds credo and clean up based on rules\n- Update dependencies\n- Fix documentation","ref":"changelog.html#changed"},{"type":"extras","title":"2.1.1 (2019-10-21) - Changelog","doc":"","ref":"changelog.html#2-1-1-2019-10-21"},{"type":"extras","title":"Changed - Changelog","doc":"- Better error handling\n- Fix documentation formatting","ref":"changelog.html#changed"},{"type":"extras","title":"2.1.0 (2019-07-21) - Changelog","doc":"","ref":"changelog.html#2-1-0-2019-07-21"},{"type":"extras","title":"Added - Changelog","doc":"- A `by: {:conn, func}` option","ref":"changelog.html#added"},{"type":"extras","title":"1.0.0 (2018-06-23) - Changelog","doc":"","ref":"changelog.html#1-0-0-2018-06-23"},{"type":"extras","title":"Changed - Changelog","doc":"- Initial release","ref":"changelog.html#changed"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}